@@ -286,7 +286,7 @@ parse_dn(const QString &dn)
 static QString dn_escape(const QString &s)
 {
     QString result;
-    for (unsigned int i = 0, end = s.length(); i != end; ++i) {
+    for (int i = 0, end = s.length(); i != end; ++i) {
         const QChar ch = s[i];
         switch (ch.unicode()) {
         case ',':
@@ -297,10 +297,8 @@ static QString dn_escape(const QString &s)
         case '>':
         case ';':
             result += QLatin1Char('\\');
-        // fall through
-#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
-        Q_FALLTHROUGH();
-#endif
+            // fall through
+            Q_FALLTHROUGH();
         default:
             result += ch;
         }
